#ifndef TRAILGPXVIEW_H
#define TRAILGPXVIEW_H

#include <QWidget>
#include <QtLocation/QGeoMapPolylineObject>

class MapWidget;
class QWebView;
class QVBoxLayout;
class TrailInterface;

class TrailGPXView : public QWidget
{
    Q_OBJECT
public:
    explicit TrailGPXView(TrailInterface*, QWidget *parent = 0);

    void addMapObject(QtMobility::QGeoMapPolylineObject*, bool fit);
    void clearMapObjects();

signals:

public slots:

private:
    MapWidget *m_map;

    QVBoxLayout *m_layout;
};

#endif // TRAILGPXVIEW_H
